@@ -1,5 +1,4 @@
 package Application::Pipeline::Services::DBI;
-$VERSION = '0.1.1';
 
 #-- pragmas ---------------------------- 
  use strict;
@@ -24,7 +23,7 @@ $dbh = $pipeline->dbh;
 our $dbh = undef;
 
 sub load {
-    my( $class, $pipeline, @args ) = @_;
+    my( $class, $pipeline @args ) = @_;
     $dbh ||= DBI->connect( @args );
 
     $pipeline->addServices( dbh => $dbh );
